KoiPrintStyle enum

打印样式 (正常/加大)。 Print style — normal or enlarged text.

来源: 旧 XIISenderPrintStyle KoiPrintStyle. KoiPrintStyle. 打印样式定义。

Inheritance
Available extensions

Values

normal → const KoiPrintStyle

正常模式

large → const KoiPrintStyle

加大模式

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KoiPrintStyle>
A constant List of the values in this enum, in order of their declaration.